@@ -57,8 +57,8 @@ Environment Variables
 
 """
 # Munin  - Magic Markers
-#%# family=manual
-#%# capabilities=noautoconf nosuggest
+#%# family=auto
+#%# capabilities=autoconf nosuggest
 
 import sys
 from pymunin import MuninGraph, MuninPlugin, muninMain
@@ -93,7 +93,7 @@ class MuninPgPlugin(MuninPlugin):
         
         self.envRegisterFilter('db', '^\w+$')
         self._host = self.envGet('host')
-        self._port = self.envGet('port')
+        self._port = self.envGet('port', None, int)
         self._database = self.envGet('database')
         self._user = self.envGet('user')
         self._password = self.envGet('password')
@@ -377,6 +377,14 @@ class MuninPgPlugin(MuninPlugin):
             
         """
         return self.envCheckFilter('db', name)
+    
+    def autoconf(self):
+        """Implements Munin Plugin Auto-Configuration Option.
+        
+        @return: True if plugin can be  auto-configured, False otherwise.
+                 
+        """
+        return self._dbconn.checkVersion('7.0')
               
 
 def main():
